@@ -118,7 +118,7 @@ base$z_bis = z_bis
 # we add the fixed-effect in the formula
 result_NL_fe = femlm(z_bis~0|id, base, NL.fml = ~ log(2*x + b*y), NL.start = list(b=1), lower = list(b=0))
 # The coef should be around 3
-result_NL_fe$coef
+coef(result_NL_fe)
 # the gamma and the exponential of the fixed-effects should be similar
 rbind(gamma, exp(getFE(result_NL_fe)$id))
 
